import { useState, useEffect, useRef } from "react";
import { DefineDefaultValue } from "utils-hooks";
import { sub, add } from "../utils";
function isEmpy(val) {
    return val === undefined || val === null;
}
/**
 * 保留精度
 * @param precision
 * @param val
 */
export function coverPrecision(precision, val) {
    if (precision === undefined || val === undefined || val === "") {
        return String(val);
    }
    else {
        return parseFloat(val + "").toFixed(precision);
    }
}
/**
 * 默认格式化
 * @description 返回数值的字符串
 * @param value
 */
export var DefaultFormatter = function (value) {
    if (isEmpy(value)) {
        return "";
    }
    else {
        return value + "";
    }
};
/**
 * 默认格式化
 * @description 返回对应的反格式化字符串
 * @param value
 */
export var DefaultParser = function (value) {
    if (value) {
        return value + "";
    }
    else {
        return "";
    }
};
/**
 * 字符串转换为数值
 * @description 返回undefined则不是数值
 * @param val
 */
function coverNumber(val) {
    if (val) {
        var number = parseFloat(val + "");
        if (!isNaN(number)) {
            return number;
        }
    }
}
export default function useValue(props) {
    var min = props.min, max = props.max, _a = props.step, step = _a === void 0 ? 1 : _a, precision = props.precision, _b = props.parser, parser = _b === void 0 ? DefaultParser : _b, _c = props.formatter, formatter = _c === void 0 ? DefaultFormatter : _c, onChange = props.onChange;
    // 受控数值
    var isControll = "value" in props;
    var valueProps = DefineDefaultValue(props, "value", "defaultValue");
    // 输入框里的临时字符串
    var _d = useState(getFormatterInputValue(valueProps)), inputValue = _d[0], setInputValue = _d[1];
    // 记录最后一次输入正确的时间字符串
    var lastRef = useRef(valueProps);
    // 受控时候由外部更新输入框的值
    useEffect(function () {
        if (isControll) {
            setInputValue(getFormatterInputValue(props.value));
        }
    }, [isControll ? props.value : 1]);
    /**
     * 获取当前数值对应的输入框字符串
     * @param val
     */
    function getFormatterInputValue(val) {
        var numberValue = getParserNumber(val);
        return formatter(isEmpy(numberValue) ? "" : numberValue + "");
    }
    /**
     * 解析为数值字符串
     * @param val
     */
    function getParserNumber(val) {
        return parser(isEmpy(val) ? "" : val + "");
    }
    /**
     * 改变值
     * @param val
     */
    function changeValue(val) {
        if (props.disabled) {
            return;
        }
        var numberValue = coverNumber(coverPrecision(precision, getParserNumber(val)));
        if (numberValue === undefined) {
            numberValue = lastRef.current;
        }
        if (min !== undefined && numberValue < min) {
            numberValue = min;
        }
        if (max !== undefined && numberValue > max) {
            numberValue = max;
        }
        if (getParserNumber(val) === "") {
            numberValue = null;
        }
        lastRef.current = numberValue;
        if (!isControll || getFormatterInputValue(numberValue) !== val) {
            setInputValue(getFormatterInputValue(numberValue));
        }
        if (onChange) {
            onChange(numberValue);
        }
    }
    /**
     * 是否可以自增
     */
    function canIncrease(getNextValue) {
        var numberValue = coverNumber(getParserNumber(lastRef.current));
        if (max !== undefined && numberValue !== undefined) {
            return numberValue < max;
        }
        else {
            return true;
        }
    }
    /**
     * 是否可以自减
     */
    function canDecrease(getNextValue) {
        var numberValue = coverNumber(getParserNumber(lastRef.current));
        if (min !== undefined && numberValue !== undefined) {
            return numberValue > min;
        }
        else {
            return true;
        }
    }
    /**
     * 自增值
     */
    function increase() {
        if (!canIncrease()) {
            return;
        }
        // 计算自增值
        var numberValue = coverNumber(getParserNumber(lastRef.current)) || 0;
        var next;
        if (max !== undefined) {
            if (add(numberValue, step) > max) {
                next = max;
            }
            else {
                next = add(numberValue, step);
            }
        }
        else {
            next = add(numberValue, step);
        }
        changeValue(next + "");
    }
    /**
     * 自减值
     */
    function decrease() {
        if (!canDecrease()) {
            return;
        }
        // 计算自减值
        var numberValue = coverNumber(getParserNumber(lastRef.current)) || 0;
        var next;
        if (min !== undefined) {
            if (sub(numberValue, step) < min) {
                next = min;
            }
            else {
                next = sub(numberValue, step);
            }
        }
        else {
            next = sub(numberValue, step);
        }
        changeValue(next + "");
    }
    return [getFormatterInputValue, inputValue, setInputValue, changeValue, canIncrease, canDecrease, increase, decrease];
}
//# sourceMappingURL=useValue.js.map